@@ -38,6 +38,9 @@ find_formula <- function(x, ...) {
 
 
 
+# Default method -----------------------------------
+
+
 #' @export
 find_formula.default <- function(x, ...) {
   if (inherits(x, "list") && .obj_has_name(x, "gam")) {
@@ -64,6 +67,23 @@ find_formula.data.frame <- function(x, ...) {
 
 
 
+#' @export
+find_formula.aovlist <- function(x, ...) {
+  f <- attr(x, "terms", exact = TRUE)
+  attributes(f) <- NULL
+  list(conditional = f)
+}
+
+
+
+
+
+
+
+
+# GAM -----------------------------------------------------------
+
+
 #' @export
 find_formula.gam <- function(x, ...) {
   f <- tryCatch(
@@ -129,6 +149,7 @@ find_formula.gamlss <- function(x, ...) {
 }
 
 
+
 #' @importFrom stats as.formula
 #' @export
 find_formula.bamlss <- function(x, ...) {
@@ -151,6 +172,12 @@ find_formula.gamm <- function(x, ...) {
 
 
 
+
+
+
+# Other models ----------------------------------------------
+
+
 #' @export
 find_formula.gee <- function(x, ...) {
   tryCatch(
@@ -174,6 +201,19 @@ find_formula.gee <- function(x, ...) {
 
 
 
+#' @export
+find_formula.MANOVA <- function(x, ...) {
+  .compact_list(list(
+    conditional = x$input$formula,
+    random = stats::as.formula(paste0("~", x$input$subject))
+  ))
+}
+
+#' @export
+find_formula.RM <- find_formula.MANOVA
+
+
+
 #' @export
 find_formula.gls <- function(x, ...) {
   ## TODO this is an intermediate fix to return the correlation variables from gls-objects
@@ -219,6 +259,17 @@ find_formula.LORgee <- function(x, ...) {
 
 
 
+
+
+
+
+
+
+
+
+# Panel data models ---------------------------------------
+
+
 #' @export
 find_formula.ivreg <- function(x, ...) {
   tryCatch(
@@ -296,33 +347,6 @@ find_formula.plm <- function(x, ...) {
 
 
 
-#' @export
-find_formula.coxme <- function(x, ...) {
-  if (!requireNamespace("lme4", quietly = TRUE)) {
-    stop("To use this function, please install package 'lme4'.")
-  }
-
-  f.cond <- stats::formula(x)
-
-  f.random <- lapply(lme4::findbars(f.cond), function(.x) {
-    f <- .safe_deparse(.x)
-    stats::as.formula(paste0("~", f))
-  })
-
-  if (length(f.random) == 1) {
-    f.random <- f.random[[1]]
-  }
-
-  f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
-
-  .compact_list(list(
-    conditional = f.cond,
-    random = f.random
-  ))
-}
-
-
-
 #' @export
 find_formula.felm <- function(x, ...) {
   f <- .safe_deparse(stats::formula(x))
@@ -358,6 +382,34 @@ find_formula.felm <- function(x, ...) {
 
 
 
+#' @export
+find_formula.feglm <- function(x, ...) {
+  f <- .safe_deparse(stats::formula(x))
+  f_parts <- unlist(strsplit(f, "(?<!\\()\\|(?![\\w\\s\\+\\(~]*[\\)])", perl = TRUE))
+
+  f.cond <- .trim(f_parts[1])
+
+  if (length(f_parts) > 1) {
+    f.instr <- paste0("~", .trim(f_parts[2]))
+  } else {
+    f.instr <- NULL
+  }
+
+  if (length(f_parts) > 2) {
+    f.clus <- paste0("~", .trim(f_parts[3]))
+  } else {
+    f.clus <- NULL
+  }
+
+  .compact_list(list(
+    conditional = stats::as.formula(f.cond),
+    instruments = stats::as.formula(f.instr),
+    cluster = stats::as.formula(f.clus)
+  ))
+}
+
+
+
 #' @export
 find_formula.fixest <- function(x, ...) {
   f <- .safe_deparse(stats::formula(x))
@@ -426,8 +478,17 @@ find_formula.wbm <- function(x, ...) {
   if (length(f_parts) > 2) {
     f_parts[3] <- .trim(f_parts[3])
     if (grepl("\\((.+)\\|(.+)\\)", f_parts[3])) {
-      f.rand <- gsub("(\\(|\\))", "", f_parts[3])
-      f.rand <- paste0("~", .trim(f.rand))
+      # we have multiple random effects, which we can better extract
+      # via "lme4::findbars()"
+      if (length(gregexpr("\\|", f_parts[3])[[1]]) > 1) {
+        if (!requireNamespace("lme4", quietly = TRUE)) {
+          stop("To use this function, please install package 'lme4'.")
+        }
+        f.rand <- lme4::findbars(stats::as.formula(paste("~", f_parts[3])))
+      } else {
+        f.rand <- gsub("(\\(|\\))", "", f_parts[3])
+        f.rand <- stats::as.formula(paste0("~", .trim(f.rand)))
+      }
       f.clint <- NULL
     } else {
       ## TODO dangerous fix to convert cross-level interactions
@@ -445,28 +506,14 @@ find_formula.wbm <- function(x, ...) {
     conditional = stats::as.formula(f.cond),
     instruments = stats::as.formula(f.instr),
     interactions = stats::as.formula(f.clint),
-    random = stats::as.formula(f.rand)
+    random = f.rand
   ))
 }
 
-
 #' @export
 find_formula.wbgee <- find_formula.wbm
 
 
-#' @export
-find_formula.BBmm <- function(x, ...) {
-  f.cond <- parse(text = .safe_deparse(x$call))[[1]]$fixed.formula
-  f.rand <- parse(text = .safe_deparse(x$call))[[1]]$random.formula
-
-  .compact_list(list(
-    conditional = stats::as.formula(f.cond),
-    random = stats::as.formula(f.rand)
-  ))
-}
-
-
-
 #' @export
 find_formula.glimML <- function(x, ...) {
   .compact_list(list(
@@ -491,53 +538,64 @@ find_formula.tobit <- function(x, ...) {
 
 
 
+
+
+# Zero inflated models --------------------------------------
+
+
 #' @export
 find_formula.hurdle <- function(x, ...) {
   .zeroinf_formula(x)
 }
 
-
+#' @export
+find_formula.zeroinfl <- find_formula.hurdle
 
 #' @export
-find_formula.zeroinfl <- function(x, ...) {
-  .zeroinf_formula(x)
-}
+find_formula.zerotrunc <- find_formula.hurdle
 
 
 
-#' @export
-find_formula.zerotrunc <- function(x, ...) {
-  .zeroinf_formula(x)
-}
 
 
 
+
+
+# Ordinal models  --------------------------------------
+
+
+#' @importFrom stats as.formula
 #' @export
 find_formula.clmm2 <- function(x, ...) {
-  list(
+  .compact_list(list(
     conditional = stats::as.formula(.safe_deparse(attr(x$location, "terms", exact = TRUE))),
+    scale = stats::as.formula(.safe_deparse(attr(x$scale, "terms", exact = TRUE))),
     random = stats::as.formula(paste0("~", parse(text = .safe_deparse(x$call))[[1]]$random))
-  )
+  ))
 }
 
 
-
+#' @importFrom stats formula
 #' @export
 find_formula.clm2 <- function(x, ...) {
-  list(conditional = attr(x$location, "terms", exact = TRUE))
+  .compact_list(list(
+    conditional = stats::formula(attr(x$location, "terms", exact = TRUE)),
+    scale = stats::formula(attr(x$scale, "terms", exact = TRUE))
+  ))
 }
 
 
 
-#' @export
-find_formula.aovlist <- function(x, ...) {
-  f <- attr(x, "terms", exact = TRUE)
-  attributes(f) <- NULL
-  list(conditional = f)
-}
 
 
 
+
+
+
+
+# Mixed models -----------------------
+
+
 #' @export
 find_formula.glmmTMB <- function(x, ...) {
   if (!requireNamespace("lme4", quietly = TRUE)) {
@@ -601,8 +659,7 @@ find_formula.nlmerMod <- function(x, ...) {
     stop("To use this function, please install package 'lme4'.")
   }
 
-  f.cond <- stats::formula(x)
-  f.random <- lapply(lme4::findbars(f.cond), function(.x) {
+  f.random <- lapply(lme4::findbars(stats::formula(x)), function(.x) {
     f <- .safe_deparse(.x)
     stats::as.formula(paste0("~", f))
   })
@@ -611,10 +668,8 @@ find_formula.nlmerMod <- function(x, ...) {
     f.random <- f.random[[1]]
   }
 
-  fx <- .get_fixed_effects(f.cond)
-
-  f.cond <- stats::as.formula(gsub("(.*)(~)(.*)~(.*)", "\\1\\2\\4", fx))
-  f.nonlin <- stats::as.formula(paste0("~", .trim(gsub("(.*)~(.*)~(.*)", "\\2", fx))))
+  f.cond <- lme4::nobars(stats::as.formula(gsub("(.*)(~)(.*)~(.*)", "\\1\\2\\4", .safe_deparse(stats::formula(x)))))
+  f.nonlin <- stats::as.formula(paste0("~", .trim(gsub("(.*)~(.*)~(.*)", "\\2", .safe_deparse(stats::formula(x))))))
 
   .compact_list(list(
     conditional = f.cond,
@@ -642,80 +697,102 @@ find_formula.merMod <- function(x, ...) {
   }
 
   f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
-
   .compact_list(list(conditional = f.cond, random = f.random))
 }
 
+#' @export
+find_formula.rlmerMod <- find_formula.merMod
+
+#' @export
+find_formula.cpglmm <- find_formula.merMod
+
+#' @export
+find_formula.glmmadmb <- find_formula.merMod
+
+#' @export
+find_formula.mixed <- find_formula.merMod
+
+#' @export
+find_formula.clmm <- find_formula.merMod
+
+#' @export
+find_formula.cgamm <- find_formula.merMod
+
+#' @export
+find_formula.coxme <- find_formula.merMod
+
+
+
+#' @export
+find_formula.lme <- function(x, ...) {
+  fm <- eval(x$call$fixed)
+  fmr <- eval(x$call$random)
+  ## TODO this is an intermediate fix to return the correlation variables from lme-objects
+  fc <- parse(text = .safe_deparse(x$call$correlation))[[1]]$form
+
+  .compact_list(list(
+    conditional = fm,
+    random = fmr,
+    correlation = stats::as.formula(fc)
+  ))
+}
+
 
 
 #' @export
-find_formula.rlmerMod <- function(x, ...) {
-  if (!requireNamespace("lme4", quietly = TRUE)) {
-    stop("To use this function, please install package 'lme4'.")
+find_formula.mixor <- function(x, ...) {
+  fm <- x$call$formula
+
+  f_id <- deparse(x$call$id)
+  f_rs <- x$call$which.random.slope
+
+  if (!is.null(f_rs)) {
+    f_rs <- trimws(unlist(strsplit(.safe_deparse(x$call$formula[[3]]), "\\+")))[f_rs]
+    fmr <- paste(f_rs, "|", f_id)
+  } else {
+    fmr <- f_id
   }
 
-  f.cond <- stats::formula(x)
-  f.random <- lapply(lme4::findbars(f.cond), function(.x) {
-    f <- .safe_deparse(.x)
-    stats::as.formula(paste0("~", f))
-  })
+  fmr <- stats::as.formula(paste("~", fmr))
 
-  if (length(f.random) == 1) {
-    f.random <- f.random[[1]]
-  }
-
-  f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
-
-  .compact_list(list(conditional = f.cond, random = f.random))
+  .compact_list(list(
+    conditional = fm,
+    random = fmr
+  ))
 }
 
 
 
 #' @export
-find_formula.mixed <- function(x, ...) {
-  if (!requireNamespace("lme4", quietly = TRUE)) {
-    stop("To use this function, please install package 'lme4'.")
-  }
-
+find_formula.MixMod <- function(x, ...) {
   f.cond <- stats::formula(x)
-  f.random <- lapply(lme4::findbars(f.cond), function(.x) {
-    f <- .safe_deparse(.x)
-    stats::as.formula(paste0("~", f))
-  })
+  f.zi <- stats::formula(x, type = "zi_fixed")
+  f.random <- stats::formula(x, type = "random")
+  f.zirandom <- stats::formula(x, type = "zi_random")
 
-  if (length(f.random) == 1) {
-    f.random <- f.random[[1]]
-  }
-
-  f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
-
-  .compact_list(list(conditional = f.cond, random = f.random))
+  .compact_list(list(
+    conditional = f.cond,
+    random = f.random,
+    zero_inflated = f.zi,
+    zero_inflated_random = f.zirandom
+  ))
 }
 
 
 
 #' @export
-find_formula.clmm <- function(x, ...) {
-  if (!requireNamespace("lme4", quietly = TRUE)) {
-    stop("To use this function, please install package 'lme4'.")
-  }
+find_formula.BBmm <- function(x, ...) {
+  f.cond <- parse(text = .safe_deparse(x$call))[[1]]$fixed.formula
+  f.rand <- parse(text = .safe_deparse(x$call))[[1]]$random.formula
 
-  f.cond <- stats::formula(x)
-  f.random <- lapply(lme4::findbars(f.cond), function(.x) {
-    f <- .safe_deparse(.x)
-    stats::as.formula(paste0("~", f))
-  })
-
-  if (length(f.random) == 1) {
-    f.random <- f.random[[1]]
-  }
-
-  f.cond <- stats::as.formula(.get_fixed_effects(f.cond))
-
-  .compact_list(list(conditional = f.cond, random = f.random))
+  .compact_list(list(
+    conditional = stats::as.formula(f.cond),
+    random = stats::as.formula(f.rand)
+  ))
 }
 
 
+
 #' @export
 find_formula.mmclogit <- function(x, ...) {
   tryCatch(
@@ -733,6 +810,12 @@ find_formula.mmclogit <- function(x, ...) {
 
 
 
+
+
+
+# Bayesian models --------------------------------
+
+
 #' @export
 find_formula.stanreg <- function(x, ...) {
   if (!requireNamespace("lme4", quietly = TRUE)) {
@@ -791,39 +874,6 @@ find_formula.MCMCglmm <- function(x, ...) {
 
 
 
-#' @export
-find_formula.lme <- function(x, ...) {
-  fm <- eval(x$call$fixed)
-  fmr <- eval(x$call$random)
-  ## TODO this is an intermediate fix to return the correlation variables from lme-objects
-  fc <- parse(text = .safe_deparse(x$call$correlation))[[1]]$form
-
-  .compact_list(list(
-    conditional = fm,
-    random = fmr,
-    correlation = stats::as.formula(fc)
-  ))
-}
-
-
-
-#' @export
-find_formula.MixMod <- function(x, ...) {
-  f.cond <- stats::formula(x)
-  f.zi <- stats::formula(x, type = "zi_fixed")
-  f.random <- stats::formula(x, type = "random")
-  f.zirandom <- stats::formula(x, type = "zi_random")
-
-  .compact_list(list(
-    conditional = f.cond,
-    random = f.random,
-    zero_inflated = f.zi,
-    zero_inflated_random = f.zirandom
-  ))
-}
-
-
-
 #' @importFrom utils tail
 #' @export
 find_formula.BFBayesFactor <- function(x, ...) {
@@ -854,6 +904,14 @@ find_formula.BFBayesFactor <- function(x, ...) {
 
 
 
+
+
+
+
+
+# helper ---------------------------
+
+
 .get_brms_formula <- function(f) {
   if (!requireNamespace("lme4", quietly = TRUE)) {
     stop("To use this function, please install package 'lme4'.")
@@ -981,8 +1039,8 @@ find_formula.BFBayesFactor <- function(x, ...) {
   # fix dot-formulas
   tryCatch(
     {
-      if (as.character(f[3]) == ".") {
-        resp <- .safe_deparse(f[2])
+      if (as.character(f[[3]])[1] == ".") {
+        resp <- .safe_deparse(f[[2]])
         pred <- setdiff(colnames(.get_data_from_env(model)), resp)
         f <- stats::as.formula(paste(resp, "~", paste0(pred, collapse = " + ")))
       }
