@@ -21,16 +21,20 @@ is_model <- function(x) {
   inherits(
     x,
     c(
+      "_ranger",
       "aareg",
       "anova",
+      "Anova.mlm",
       "aov",
       "aovlist",
       "Arima",
       "bamlss",
       "bamlss.frame",
+      "bayesmeta",
       "bayesx",
       "BBmm",
       "BBreg",
+      "bcplm",
       "betareg",
       "BFBayesFactor",
       "bglmerMod",
@@ -39,6 +43,7 @@ is_model <- function(x) {
       "blavaan",
       "blmerMod",
       "bracl",
+      "brglm",
       "brglmFit",
       "brmsfit",
       "brmultinom",
@@ -47,20 +52,25 @@ is_model <- function(x) {
       "censReg",
       "cgam",
       "cgamm",
+      "cglm",
       "clm",
       "clm2",
       "clmm",
       "clmm2",
+      "coeftest",
       "complmrob",
       "confusionMatrix",
       "coxme",
       "coxph",
+      "cpglm",
+      "cpglmm",
       "crch",
       "crq",
       "drc",
       "emmGrid",
       "epi.2by2",
       "ergm",
+      "feglm",
       "feis",
       "felm",
       "fitdistr",
@@ -96,6 +106,7 @@ is_model <- function(x) {
       "glmnet",
       "glmrob",
       "glmRob",
+      "glmx",
       "gls",
       "gmnl",
       "gmm",
@@ -111,12 +122,14 @@ is_model <- function(x) {
       "lmRob",
       "loggammacenslmrob",
       "logistf",
+      "LogitBoost",
       "loo",
       "LORgee",
       "lmodel2",
       "lqmm",
       "lrm",
       "manova",
+      "MANOVA",
       "mboostLSS",
       "mclogit",
       "mmclogit",
@@ -125,12 +138,14 @@ is_model <- function(x) {
       "mediate",
       "merMod",
       "mixed",
+      "mixor",
       "MixMod",
       "mjoint",
       "mle2",
       "mlm",
       "mlogit",
       "multinom",
+      "mvmeta",
       "mvr",
       "negbin",
       "nlreg",
@@ -149,6 +164,7 @@ is_model <- function(x) {
       "rlm",
       "rlme",
       "rlmerMod",
+      "RM",
       "rma",
       "rma.uni",
       "rms",
@@ -171,6 +187,7 @@ is_model <- function(x) {
       "vglm",
       "wbm",
       "wblm",
+      "zcpglm",
       "zeroinfl",
       "zerotrunc"
     )
