@@ -51,9 +51,12 @@ supported_models <- function() {
     "bigglm",
     "blavaan",
     "bracl",
+    "brglm",
     "brmsfit",
     "brmultinom",
     "censReg",
+    "cgam",
+    "cgamm",
     "clm",
     "clm2",
     "clmm",
@@ -61,10 +64,13 @@ supported_models <- function() {
     "complmrob",
     "coxme",
     "coxph",
+    "cpglm",
+    "cpglmm",
     "crch",
     "crq",
     "feis",
     "felm",
+    "feglm",
     "fixest",
     "flexsurvreg",
     "gam",
@@ -77,10 +83,12 @@ supported_models <- function() {
     "geeglm",
     "glimML",
     "glm",
+    "glmmadmb",
     "glmmPQL",
     "glmmTMB",
     "glmrob",
     "glmRob",
+    "glmx",
     "gls",
     "gmnl",
     "htest",
@@ -96,21 +104,25 @@ supported_models <- function() {
     "logistf",
     "LORgee",
     "lrm",
-    "ols",
+    "MANOVA",
+    "mcmc",
     "MCMCglmm",
     "merMod",
     "mixed",
+    "mixor",
     "MixMod",
     "mlm",
     "mclogit",
     "mlogit",
     "mmlogit",
     "multinom",
+    "ols",
     "plm",
     "polr",
     "psm",
     "rlm",
     "rlmerMod",
+    "RM",
     "rma",
     "rma.uni",
     "rq",
