@@ -163,9 +163,21 @@ model_info.mixed <- model_info.mmclogit
 #' @export
 model_info.plm <- model_info.mmclogit
 
+#' @export
+model_info.mcmc <- model_info.mmclogit
+
 #' @export
 model_info.gls <- model_info.mmclogit
 
+#' @export
+model_info.nls <- model_info.mmclogit
+
+#' @export
+model_info.MANOVA <- model_info.mmclogit
+
+#' @export
+model_info.RM <- model_info.mmclogit
+
 #' @export
 model_info.truncreg <- model_info.mmclogit
 
@@ -266,6 +278,9 @@ model_info.clm2 <- model_info.clm
 #' @export
 model_info.clmm <- model_info.clm
 
+#' @export
+model_info.mixor <- model_info.clm
+
 
 
 
@@ -372,6 +387,19 @@ model_info.MixMod <- function(x, ...) {
 model_info.glmmPQL <- model_info.MixMod
 
 
+#' @export
+model_info.glmx <- function(x, ...) {
+  faminfo <- x$family$glm
+  .make_family(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = faminfo$link == "logit",
+    link.fun = faminfo$link,
+    ...
+  )
+}
+
+
 #' @export
 model_info.fixest <- function(x, ...) {
   faminfo <- x$family
@@ -410,7 +438,8 @@ model_info.fixest <- function(x, ...) {
   }
 }
 
-
+#' @export
+model_info.feglm <- model_info.fixest
 
 
 
@@ -557,6 +586,19 @@ model_info.stanmvreg <- function(x, ...) {
 # Other models ----------------------------
 
 
+#' @export
+model_info.cgam <- function(x, ...) {
+  faminfo <- x$family
+  .make_family(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = faminfo$link == "logit",
+    link.fun = faminfo$link,
+    ...
+  )
+}
+
+
 #' @export
 model_info.gamm <- function(x, ...) {
   x <- x$gam
@@ -611,6 +653,38 @@ model_info.BBmm <- model_info.BBreg
 
 
 
+#' @export
+model_info.glmmadmb <- function(x, ...) {
+  .make_family(
+    x = x,
+    fitfam = x$family,
+    logit.link = x$link == "logit",
+    multi.var = FALSE,
+    zero.inf = x$zeroInflation,
+    link.fun = x$link,
+    ...
+  )
+}
+
+
+#' @export
+model_info.cpglmm <- function(x, ...) {
+  link <- parse(text = .safe_deparse(x@call))[[1]]$link
+  if (is.numeric(link)) link <- "tweedie"
+  .make_family(
+    x = x,
+    fitfam = "poisson",
+    logit.link = FALSE,
+    multi.var = FALSE,
+    link.fun = link,
+    ...
+  )
+}
+
+#' @export
+model_info.cpglm <- model_info.cpglmm
+
+
 #' @export
 model_info.glimML <- function(x, ...) {
   fitfam <- switch(x@method, BB = "betabinomial", NB = "negative binomial")
